==> jc-1.4.0.tar.gz: gnu/xml/dom/ls/WriterOutputStream.h <==
// public class gnu.xml.dom.ls.WriterOutputStream

// class file dependencies
// @dep_class e33277b998541c94 gnu_xml_dom_ls_WriterOutputStream
// @dep_class 4026d3144d6654d8 java_io_OutputStream
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_io_OutputStream

#include "java/io/OutputStream.h"

#ifndef _JC_gnu_xml_dom_ls_WriterOutputStream_H_
#define _JC_gnu_xml_dom_ls_WriterOutputStream_H_

// Forward structure declarations
struct _jc_java_io_Writer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_dom_ls_WriterOutputStream$sub_refs	_jc_gnu_xml_dom_ls_WriterOutputStream$sub_refs;
typedef struct _jc_gnu_xml_dom_ls_WriterOutputStream$sub_nonrefs	_jc_gnu_xml_dom_ls_WriterOutputStream$sub_nonrefs;
typedef struct _jc_gnu_xml_dom_ls_WriterOutputStream$refs	_jc_gnu_xml_dom_ls_WriterOutputStream$refs;
typedef struct _jc_gnu_xml_dom_ls_WriterOutputStream$nonrefs	_jc_gnu_xml_dom_ls_WriterOutputStream$nonrefs;
typedef struct _jc_gnu_xml_dom_ls_WriterOutputStream$object	_jc_gnu_xml_dom_ls_WriterOutputStream$object;

typedef const struct _jc_gnu_xml_dom_ls_WriterOutputStream$vmethods	_jc_gnu_xml_dom_ls_WriterOutputStream$vmethods;
typedef const struct _jc_gnu_xml_dom_ls_WriterOutputStream$vtable	_jc_gnu_xml_dom_ls_WriterOutputStream$vtable;
typedef const struct _jc_gnu_xml_dom_ls_WriterOutputStream$vtype	_jc_gnu_xml_dom_ls_WriterOutputStream$vtype;

// Constructors
extern void _jc_gnu_xml_dom_ls_WriterOutputStream$method$_init$514f7e161933236e(_jc_env *, struct _jc_gnu_xml_dom_ls_WriterOutputStream$object *, struct _jc_java_io_Writer$object *);

// Virtual methods
extern void _jc_gnu_xml_dom_ls_WriterOutputStream$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_gnu_xml_dom_ls_WriterOutputStream$object *);
extern void _jc_gnu_xml_dom_ls_WriterOutputStream$method$flush$9dedb7d85e88cf56(_jc_env *, struct _jc_gnu_xml_dom_ls_WriterOutputStream$object *);
extern void _jc_gnu_xml_dom_ls_WriterOutputStream$method$setEncoding$f931920c5b28493d(_jc_env *, struct _jc_gnu_xml_dom_ls_WriterOutputStream$object *, struct _jc_java_lang_String$object *);
extern void _jc_gnu_xml_dom_ls_WriterOutputStream$method$write$6377ac6964854eb2(_jc_env *, struct _jc_gnu_xml_dom_ls_WriterOutputStream$object *, jint);
extern void _jc_gnu_xml_dom_ls_WriterOutputStream$method$write$18e189e8fc25f121(_jc_env *, struct _jc_gnu_xml_dom_ls_WriterOutputStream$object *, struct _jc_byte_array *);
extern void _jc_gnu_xml_dom_ls_WriterOutputStream$method$write$306a698343ec27e8(_jc_env *, struct _jc_gnu_xml_dom_ls_WriterOutputStream$object *, struct _jc_byte_array *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_dom_ls_WriterOutputStream$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_gnu_xml_dom_ls_WriterOutputStream$method_info$flush$9dedb7d85e88cf56;
extern _jc_method _jc_gnu_xml_dom_ls_WriterOutputStream$method_info$setEncoding$f931920c5b28493d;
extern _jc_method _jc_gnu_xml_dom_ls_WriterOutputStream$method_info$write$6377ac6964854eb2;
extern _jc_method _jc_gnu_xml_dom_ls_WriterOutputStream$method_info$write$18e189e8fc25f121;
extern _jc_method _jc_gnu_xml_dom_ls_WriterOutputStream$method_info$write$306a698343ec27e8;

// Virtual methods structure
struct _jc_gnu_xml_dom_ls_WriterOutputStream$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_gnu_xml_dom_ls_WriterOutputStream$object *);
	void	(*flush$9dedb7d85e88cf56)(_jc_env *, struct _jc_gnu_xml_dom_ls_WriterOutputStream$object *);
	void	(*setEncoding$f931920c5b28493d)(_jc_env *, struct _jc_gnu_xml_dom_ls_WriterOutputStream$object *, struct _jc_java_lang_String$object *);
	void	(*write$6377ac6964854eb2)(_jc_env *, struct _jc_gnu_xml_dom_ls_WriterOutputStream$object *, jint);
	void	(*write$18e189e8fc25f121)(_jc_env *, struct _jc_gnu_xml_dom_ls_WriterOutputStream$object *, struct _jc_byte_array *);
	void	(*write$306a698343ec27e8)(_jc_env *, struct _jc_gnu_xml_dom_ls_WriterOutputStream$object *, struct _jc_byte_array *, jint, jint);
};

// Vtable
struct _jc_gnu_xml_dom_ls_WriterOutputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_OutputStream$vmethods	java_io_OutputStream;
	_jc_gnu_xml_dom_ls_WriterOutputStream$vmethods	gnu_xml_dom_ls_WriterOutputStream;
};

// Vtype
struct _jc_gnu_xml_dom_ls_WriterOutputStream$vtype {
	_jc_type			type;
	_jc_gnu_xml_dom_ls_WriterOutputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_dom_ls_WriterOutputStream$sub_refs {
	struct _jc_java_io_Writer$object	*writer;
	struct _jc_java_lang_String$object	*encoding;
};

// Reference instance fields (object)
struct _jc_gnu_xml_dom_ls_WriterOutputStream$refs {
    _jc_gnu_xml_dom_ls_WriterOutputStream$sub_refs	gnu_xml_dom_ls_WriterOutputStream;
    _jc_java_io_OutputStream$sub_refs	java_io_OutputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_dom_ls_WriterOutputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_dom_ls_WriterOutputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_OutputStream$sub_nonrefs	java_io_OutputStream;
    _jc_gnu_xml_dom_ls_WriterOutputStream$sub_nonrefs	gnu_xml_dom_ls_WriterOutputStream;
};

// Object instance structure
struct _jc_gnu_xml_dom_ls_WriterOutputStream$object {
	_jc_gnu_xml_dom_ls_WriterOutputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_dom_ls_WriterOutputStream$vtype	*vtype;
	_jc_gnu_xml_dom_ls_WriterOutputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_dom_ls_WriterOutputStream$vtype _jc_gnu_xml_dom_ls_WriterOutputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_dom_ls_WriterOutputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_dom_ls_WriterOutputStream$class_object;

#endif	/* _JC_gnu_xml_dom_ls_WriterOutputStream_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/dom/ls/WriterOutputStream.h <==
// public class gnu.xml.dom.ls.WriterOutputStream

// class file dependencies
// @dep_class e33277b998541c94 gnu_xml_dom_ls_WriterOutputStream
// @dep_class 4026d3144d6654d8 java_io_OutputStream
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_io_OutputStream

#include "java/io/OutputStream.h"

#ifndef _JC_gnu_xml_dom_ls_WriterOutputStream_H_
#define _JC_gnu_xml_dom_ls_WriterOutputStream_H_

// Forward structure declarations
struct _jc_java_io_Writer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_dom_ls_WriterOutputStream$sub_refs	_jc_gnu_xml_dom_ls_WriterOutputStream$sub_refs;
typedef struct _jc_gnu_xml_dom_ls_WriterOutputStream$sub_nonrefs	_jc_gnu_xml_dom_ls_WriterOutputStream$sub_nonrefs;
typedef struct _jc_gnu_xml_dom_ls_WriterOutputStream$refs	_jc_gnu_xml_dom_ls_WriterOutputStream$refs;
typedef struct _jc_gnu_xml_dom_ls_WriterOutputStream$nonrefs	_jc_gnu_xml_dom_ls_WriterOutputStream$nonrefs;
typedef struct _jc_gnu_xml_dom_ls_WriterOutputStream$object	_jc_gnu_xml_dom_ls_WriterOutputStream$object;

typedef const struct _jc_gnu_xml_dom_ls_WriterOutputStream$vmethods	_jc_gnu_xml_dom_ls_WriterOutputStream$vmethods;
typedef const struct _jc_gnu_xml_dom_ls_WriterOutputStream$vtable	_jc_gnu_xml_dom_ls_WriterOutputStream$vtable;
typedef const struct _jc_gnu_xml_dom_ls_WriterOutputStream$vtype	_jc_gnu_xml_dom_ls_WriterOutputStream$vtype;

// Constructors
extern void _jc_gnu_xml_dom_ls_WriterOutputStream$method$_init$514f7e161933236e(_jc_env *, struct _jc_gnu_xml_dom_ls_WriterOutputStream$object *, struct _jc_java_io_Writer$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_xml_dom_ls_WriterOutputStream$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_gnu_xml_dom_ls_WriterOutputStream$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_dom_ls_WriterOutputStream$method$flush$9dedb7d85e88cf56(_jc_env *, struct _jc_gnu_xml_dom_ls_WriterOutputStream$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_dom_ls_WriterOutputStream$method$setEncoding$f931920c5b28493d(_jc_env *, struct _jc_gnu_xml_dom_ls_WriterOutputStream$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_dom_ls_WriterOutputStream$method$write$6377ac6964854eb2(_jc_env *, struct _jc_gnu_xml_dom_ls_WriterOutputStream$object *, jint) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_dom_ls_WriterOutputStream$method$write$18e189e8fc25f121(_jc_env *, struct _jc_gnu_xml_dom_ls_WriterOutputStream$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_dom_ls_WriterOutputStream$method$write$306a698343ec27e8(_jc_env *, struct _jc_gnu_xml_dom_ls_WriterOutputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_dom_ls_WriterOutputStream$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_gnu_xml_dom_ls_WriterOutputStream$method_info$flush$9dedb7d85e88cf56;
extern _jc_method _jc_gnu_xml_dom_ls_WriterOutputStream$method_info$setEncoding$f931920c5b28493d;
extern _jc_method _jc_gnu_xml_dom_ls_WriterOutputStream$method_info$write$6377ac6964854eb2;
extern _jc_method _jc_gnu_xml_dom_ls_WriterOutputStream$method_info$write$18e189e8fc25f121;
extern _jc_method _jc_gnu_xml_dom_ls_WriterOutputStream$method_info$write$306a698343ec27e8;

// Virtual methods structure
struct _jc_gnu_xml_dom_ls_WriterOutputStream$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_gnu_xml_dom_ls_WriterOutputStream$object *) _JC_JCNI_ATTR;
	void	(*flush$9dedb7d85e88cf56)(_jc_env *, struct _jc_gnu_xml_dom_ls_WriterOutputStream$object *) _JC_JCNI_ATTR;
	void	(*setEncoding$f931920c5b28493d)(_jc_env *, struct _jc_gnu_xml_dom_ls_WriterOutputStream$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	void	(*write$6377ac6964854eb2)(_jc_env *, struct _jc_gnu_xml_dom_ls_WriterOutputStream$object *, jint) _JC_JCNI_ATTR;
	void	(*write$18e189e8fc25f121)(_jc_env *, struct _jc_gnu_xml_dom_ls_WriterOutputStream$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
	void	(*write$306a698343ec27e8)(_jc_env *, struct _jc_gnu_xml_dom_ls_WriterOutputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_dom_ls_WriterOutputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_OutputStream$vmethods	java_io_OutputStream;
	_jc_gnu_xml_dom_ls_WriterOutputStream$vmethods	gnu_xml_dom_ls_WriterOutputStream;
};

// Vtype
struct _jc_gnu_xml_dom_ls_WriterOutputStream$vtype {
	_jc_type			type;
	_jc_gnu_xml_dom_ls_WriterOutputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_dom_ls_WriterOutputStream$sub_refs {
	struct _jc_java_io_Writer$object	*writer;
	struct _jc_java_lang_String$object	*encoding;
};

// Reference instance fields (object)
struct _jc_gnu_xml_dom_ls_WriterOutputStream$refs {
    _jc_gnu_xml_dom_ls_WriterOutputStream$sub_refs	gnu_xml_dom_ls_WriterOutputStream;
    _jc_java_io_OutputStream$sub_refs	java_io_OutputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_dom_ls_WriterOutputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_dom_ls_WriterOutputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_OutputStream$sub_nonrefs	java_io_OutputStream;
    _jc_gnu_xml_dom_ls_WriterOutputStream$sub_nonrefs	gnu_xml_dom_ls_WriterOutputStream;
};

// Object instance structure
struct _jc_gnu_xml_dom_ls_WriterOutputStream$object {
	_jc_gnu_xml_dom_ls_WriterOutputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_dom_ls_WriterOutputStream$vtype	*vtype;
	_jc_gnu_xml_dom_ls_WriterOutputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_dom_ls_WriterOutputStream$vtype _jc_gnu_xml_dom_ls_WriterOutputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_dom_ls_WriterOutputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_dom_ls_WriterOutputStream$class_object;

#endif	/* _JC_gnu_xml_dom_ls_WriterOutputStream_H_ */
